@@ -3,7 +3,7 @@ use 5.010_000;
 use strict;
 use warnings;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 our @EXPORT = qw(all_vars_ok test_vars vars_ok);
 
@@ -78,6 +78,12 @@ sub vars_ok {
 sub _vars_ok {
     my($result_handler, $file, $args) = @_;
 
+    # Perl sometimes produces Unix style paths even on Windows, which can lead
+    # to us producing error messages with a path like "lib\foo/bar.pm", which
+    # is really confusing. It's simpler to just use Unix style everywhere
+    # internally.
+    $file =~ s{\\}{/}g;
+
     my $pipe = IO::Pipe->new;
     my $pid = fork();
     if(defined $pid){
@@ -429,7 +435,7 @@ Test::Vars - Detects unused variables in perl modules
 
 =head1 VERSION
 
-This document describes Test::Vars version 0.010.
+This document describes Test::Vars version 0.011.
 
 =head1 SYNOPSIS
 
